translate.storage.statsdb

Package translate :: Package storage :: Module statsdb |
[hide private]
[frames] | no frames]

# Module statsdb

source code

Module to provide a cache of statistics in a database.

Organization: Zuza Software Foundation

Copyright: 2007 Zuza Software Foundation

License: GPL

Classes | [hide private]
| Record
| FileTotals
| StatsCache An object instantiated as a singleton for each statsfile that provides access to the database cache from a pool of StatsCache objects.

Functions | [hide private]
wordcount(string) | source code
wordsinunit(unit) Counts the words in the unit's source and target, taking plurals into account. | source code
transaction(f) Modifies f to commit database changes if it executes without exceptions. | source code
statefordb(unit) Returns the numeric database state for the unit. | source code
emptyfiletotals() Returns a dictionary with all statistics initalised to 0. | source code
emptyfilechecks() | source code
emptyfilestats() | source code
emptyunitstats() | source code
get_mod_info(file_path) | source code
suggestion_extension() | source code
suggestion_filename(filename) | source code

Variables | [hide private]
| kdepluralre = `re.compile("^_n: ")`
| brtagre = `re.compile("<br\s*?/?>")`
| xmltagre = `re.compile("<[^>]+>")`
| numberre = `re.compile("\\D\\.\\D")`
| state_strings = `{0: "untranslated", 1: "translated", 2: "fuzzy"}`

Imports: UserDict, toolkitversion, factory, multistring, Common, dbapi2, os, re, sys, stat, thread

Function Details | [hide private]

### wordsinunit(unit) | source code
Counts the words in the unit's source and target, taking plurals into account. The target words are only counted if the unit is translated.

### transaction(f) | source code
Modifies f to commit database changes if it executes without exceptions. Otherwise it rolls back the database. ALL publicly accessible methods in StatsCache MUST be decorated with this decorator.